@@ -14,44 +14,34 @@ class Client:
     BASIC_API_PATH = "/api/rest/v1/"
 
     def __init__(
-        self,
-        base_url,
-        client_id=None,
-        secret=None,
-        username=None,
-        password=None,
-        session=None,
-        auth=None,
+            self,
+            base_url: str,
+            client_id: str = None,
+            secret: str = None,
+            username: str = None,
+            password: str = None,
+            session: requests.Session = None,
     ):
-        """Expect credential
-        1) as auth, or
-        2) as client_id+secret+username+password, or
-        3) as session having an authentication."""
-        provided_auth = False
-        if not auth:
-            if client_id or secret or username or password:
-                if client_id and secret and username and password:
-                    provided_auth = True
-                    auth = Auth(base_url, client_id, secret, username, password)
-            elif session:
-                provided_auth = True
-        else:
-            provided_auth = True
-        if not provided_auth:
+        if not session and not (client_id and secret and username and password):
+            # No credentials provided neither via client_id+secret+username+password nor via session
             raise ValueError(
-                "Expect credential 1) as auth, or "
-                + "2) as client_id+secret+username+password, or "
-                + "3) as session having an authentication."
+                "Expect credentials via "
+                + "1) as client_id+secret+username+password, or "
+                + "2) as session having an authentication."
             )
+
         if not session:
             session = requests.Session()
-        self._init(base_url, session, auth)
+            session.auth = self._make_auth(base_url, client_id, secret, username, password)
 
-    def _init(self, base_url, session, auth):
+        self._init(base_url, session)
+
+    def _make_auth(self, base_url, client_id, secret, username, password) -> Auth:
+        return Auth(base_url, client_id, secret, username, password)
+
+    def _init(self, base_url, session):
         self._base_url = base_url
         self._session = session
-        if auth:
-            self._session.auth = auth
         self._session.headers.update({"Content-Type": "application/json"})
         self._resources = {
             "association_types": AssociationTypesPool(
